package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableFunction.class */
public interface FailableFunction<T, R, E extends Throwable> {
    public static final FailableFunction NOP = t -> {
        return null;
    };

    R apply(T t) throws Throwable;

    static <T, E extends Throwable> FailableFunction<T, T, E> identity() {
        return t -> {
            return t;
        };
    }

    static <T, R, E extends Throwable> FailableFunction<T, R, E> nop() {
        return NOP;
    }

    default <V> FailableFunction<T, V, E> andThen(FailableFunction<? super R, ? extends V, E> after) {
        Objects.requireNonNull(after);
        return obj -> {
            return after.apply(apply(obj));
        };
    }

    default <V> FailableFunction<V, R, E> compose(FailableFunction<? super V, ? extends T, E> before) {
        Objects.requireNonNull(before);
        return v -> {
            return apply(before.apply(v));
        };
    }
}
